import { h } from "preact";

/**
 * Renders an error page.
 * @param {{
 *   baseUrl: string
 *   basePath: string
 *   error?: string
 *   res: import("src/types/internals").NextAuthResponse
 * }} params
 */
export default function Error({
  baseUrl,
  basePath,
  error = "default",
  res
}) {
  const signinPageUrl = `${baseUrl}${basePath}/signin`;
  const errors = {
    default: {
      statusCode: 200,
      heading: "Error",
      message: h("p", null, h("a", {
        className: "site",
        href: baseUrl
      }, baseUrl.replace(/^https?:\/\//, "")))
    },
    configuration: {
      statusCode: 500,
      heading: "Server error",
      message: h("div", null, h("p", null, "There is a problem with the server configuration."), h("p", null, "Check the server logs for more information."))
    },
    accessdenied: {
      statusCode: 403,
      heading: "Access Denied",
      message: h("div", null, h("p", null, "You do not have permission to sign in."), h("p", null, h("a", {
        className: "button",
        href: signinPageUrl
      }, "Sign in")))
    },
    verification: {
      statusCode: 403,
      heading: "Unable to sign in",
      message: h("div", null, h("p", null, "The sign in link is no longer valid."), h("p", null, "It may have been used already or it may have expired.")),
      signin: h("p", null, h("a", {
        className: "button",
        href: signinPageUrl
      }, "Sign in"))
    }
  };
  const {
    statusCode,
    heading,
    message,
    signin
  } = errors[error.toLowerCase()] ?? errors.default;
  res.status(statusCode);
  return h("div", {
    className: "error"
  }, h("h1", null, heading), h("div", {
    className: "message"
  }, message), signin);
}