import { h } from "preact";
export default function Signin({
  csrfToken,
  providers,
  callbackUrl,
  email,
  error: errorType
}) {
  // We only want to render providers
  const providersToRender = providers.filter(provider => {
    if (provider.type === "oauth" || provider.type === "email") {
      // Always render oauth and email type providers
      return true;
    } else if (provider.type === "credentials" && provider.credentials) {
      // Only render credentials type provider if credentials are defined
      return true;
    } // Don't render other provider types


    return false;
  });
  const errors = {
    Signin: "Try signing in with a different account.",
    OAuthSignin: "Try signing in with a different account.",
    OAuthCallback: "Try signing in with a different account.",
    OAuthCreateAccount: "Try signing in with a different account.",
    EmailCreateAccount: "Try signing in with a different account.",
    Callback: "Try signing in with a different account.",
    OAuthAccountNotLinked: "To confirm your identity, sign in with the same account you used originally.",
    EmailSignin: "Check your email inbox.",
    CredentialsSignin: "Sign in failed. Check the details you provided are correct.",
    default: "Unable to sign in."
  };
  const error = errorType && (errors[errorType] ?? errors.default);
  return h("div", {
    className: "signin"
  }, error && h("div", {
    className: "error"
  }, h("p", null, error)), providersToRender.map((provider, i) => h("div", {
    key: provider.id,
    className: "provider"
  }, provider.type === "oauth" && h("form", {
    action: provider.signinUrl,
    method: "POST"
  }, h("input", {
    type: "hidden",
    name: "csrfToken",
    value: csrfToken
  }), callbackUrl && h("input", {
    type: "hidden",
    name: "callbackUrl",
    value: callbackUrl
  }), h("button", {
    type: "submit",
    className: "button"
  }, "Sign in with ", provider.name)), (provider.type === "email" || provider.type === "credentials") && i > 0 && providersToRender[i - 1].type !== "email" && providersToRender[i - 1].type !== "credentials" && h("hr", null), provider.type === "email" && h("form", {
    action: provider.signinUrl,
    method: "POST"
  }, h("input", {
    type: "hidden",
    name: "csrfToken",
    value: csrfToken
  }), h("label", {
    htmlFor: `input-email-for-${provider.id}-provider`
  }, "Email"), h("input", {
    id: `input-email-for-${provider.id}-provider`,
    autoFocus: true,
    type: "text",
    name: "email",
    value: email,
    placeholder: "email@example.com"
  }), h("button", {
    type: "submit"
  }, "Sign in with ", provider.name)), provider.type === "credentials" && h("form", {
    action: provider.callbackUrl,
    method: "POST"
  }, h("input", {
    type: "hidden",
    name: "csrfToken",
    value: csrfToken
  }), Object.keys(provider.credentials).map(credential => {
    return h("div", {
      key: `input-group-${provider.id}`
    }, h("label", {
      htmlFor: `input-${credential}-for-${provider.id}-provider`
    }, provider.credentials[credential].label || credential), h("input", {
      name: credential,
      id: `input-${credential}-for-${provider.id}-provider`,
      type: provider.credentials[credential].type || "text",
      value: provider.credentials[credential].value || "",
      placeholder: provider.credentials[credential].placeholder || ""
    }));
  }), h("button", {
    type: "submit"
  }, "Sign in with ", provider.name)), (provider.type === "email" || provider.type === "credentials") && i + 1 < providersToRender.length && h("hr", null))));
}